@@ -2,22 +2,30 @@ context("NMdataConf")
 
 NMdataConf(reset=TRUE)
 
+    ## can't compare functions
+dropFuns <- function(x){
+    x$as.fun <- NULL
+    x$file.mod <- NULL
+    x$file.cov <- NULL
+    x$file.ext <- NULL
+    x$file.phi <- NULL
+    x$file.shk <- NULL
+    x$modelname <- NULL
+    x
+}
+
 test_that("defaults",{
 
     fileRef <- "testReference/NMdataConf_01.rds"
     ## ref <- readRDS(fileRef)
 
     defaults <- NMdataConf()
-    defaults$as.fun <- NULL
-    defaults$file.mod <- NULL
-    defaults$file.cov <- NULL
-    defaults$file.ext <- NULL
-    defaults$file.phi <- NULL
-    defaults$modelname <- NULL
+    defaults <- dropFuns(defaults)
 
     expect_equal_to_reference(defaults,fileRef)
 
-##     compareCols(readRDS(fileRef),defaults)
+    ## compareCols(readRDS(fileRef),defaults)
+    
 })
 
 test_that("reset",{
@@ -27,18 +35,8 @@ test_that("reset",{
     NMdataConf(reset=TRUE)
     defaults2 <- NMdataConf()
 
-    defaults$as.fun <- NULL
-    defaults$file.mod <- NULL
-    defaults$file.cov <- NULL
-    defaults$file.ext <- NULL
-    defaults$file.phi <- NULL
-    defaults$modelname <- NULL
-    defaults2$as.fun <- NULL
-    defaults2$file.mod <- NULL
-    defaults2$file.cov <- NULL
-    defaults2$file.ext <- NULL
-    defaults2$file.phi <- NULL
-    defaults2$modelname <- NULL
+    defaults <- dropFuns(defaults)
+    defaults2 <- dropFuns(defaults2)
     
     
     expect_equal(defaults,defaults2)
@@ -82,19 +80,8 @@ test_that("change fun in globalenv does not affect NMdataConf()",{
     afun <- class
     defaults2 <- NMdataConf()
 
-    defaults$as.fun <- NULL
-    defaults$file.mod <- NULL
-    defaults$file.cov <- NULL
-    defaults$file.ext <- NULL
-    defaults$file.phi <- NULL
-    defaults$modelname <- NULL
-    defaults2$as.fun <- NULL
-    defaults2$file.mod <- NULL
-    defaults2$file.cov <- NULL
-    defaults2$file.ext <- NULL
-    defaults2$file.phi <- NULL
-    defaults2$modelname <- NULL
-    
+    defaults <- dropFuns(defaults)
+    defaults2 <- dropFuns(defaults2)
     
     expect_equal(defaults,defaults2)
 })
@@ -125,19 +112,8 @@ test_that("change fun in globalenv does not affect NMdataConf()",{
     afun <- class
     defaults2 <- NMdataConf()
 
-    defaults$as.fun <- NULL
-    defaults$file.mod <- NULL
-    defaults$file.cov <- NULL
-    defaults$file.ext <- NULL
-    defaults$file.phi <- NULL
-    defaults$modelname <- NULL
-
-    defaults2$as.fun <- NULL
-    defaults2$file.mod <- NULL
-    defaults2$file.cov <- NULL
-    defaults2$file.ext <- NULL
-    defaults2$file.phi <- NULL
-    defaults2$modelname <- NULL
+    defaults <- dropFuns(defaults)
+    defaults2 <- dropFuns(defaults2)
     
     expect_equal(defaults,defaults2)
 })
@@ -152,17 +128,11 @@ test_that("deprecated use.rds",{
     ## NMdataConf(use.rds=TRUE)
     NMdataConf(formats.read=c("csv"))
     new <- NMdataConf()
-    
-    new$as.fun <- NULL
-    new$file.cov <- NULL
-    new$file.mod <- NULL
-    new$file.ext <- NULL
-    new$file.phi <- NULL
-    new$modelname <- NULL
 
+    new <- dropFuns(new)
     
     expect_equal_to_reference(new,fileRef)
-    ## compareCols(readRDS(fileRef),defaults)
+    ## compareCols(readRDS(fileRef),new)
 })
 
 test_that("reset removes unknown",{
