@@ -5,7 +5,7 @@ test_that("basic",{
     fileRef <- "testReference/fnAppend_1.rds"
     
     res1 <- list(
-## numeric
+        ## numeric
         fnAppend("feww.csv",1)
        ,
         ## character
@@ -36,3 +36,15 @@ test_that("empty string does notning",{
     expect_identical(str1,str2)
 
 })
+
+test_that("multiple strings to append",{
+
+    fileRef <- "testReference/fnAppend_02.rds"
+    
+    res1 <- c(fnAppend("NMsim.rds",c("simname","sim2"))
+            ,fnAppend(c("NMsim.rds","NMsim2.rds"),c("simname","sim2"))    
+             )
+
+    expect_equal_to_reference(res1,fileRef)
+    
+})
